@@ -1,7 +1,6 @@
 from typing import Optional
 
 from pyspark.sql import Column, DataFrame
-from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 
 from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
@@ -19,22 +18,16 @@ class AutoMapperNumberDataType(AutoMapperDataTypeBase):
     def get_column_spec(
         self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
-        if isinstance(self.value, AutoMapperDataTypeLiteral) \
-                and isinstance(self.value.value, str):
-            # parse the amount here
-            column_spec = self.value.get_column_spec(
-                source_df=source_df, current_column=current_column
-            ).cast("int")
-            return column_spec
         if source_df is not None and isinstance(self.value, AutoMapperDataTypeColumn) \
-                and dict(source_df.dtypes)[self.value.value] == "string":
-            # parse the amount here
-            column_spec = self.value.get_column_spec(
-                source_df=source_df, current_column=current_column
-            ).cast("int")
-            return column_spec
-        else:
+                and dict(source_df.dtypes)[self.value.value] in ("long", "int", "bigint"):
+            # Don't parse to long if it's already a long
             column_spec = self.value.get_column_spec(
                 source_df=source_df, current_column=current_column
             )
             return column_spec
+        else:
+            # parse the amount here
+            column_spec = self.value.get_column_spec(
+                source_df=source_df, current_column=current_column
+            ).cast("long")
+            return column_spec
