@@ -10,10 +10,17 @@ from spark_auto_mapper.data_types.filter import AutoMapperFilterDataType
 from spark_auto_mapper.data_types.hash import AutoMapperHashDataType
 from spark_auto_mapper.data_types.if_ import AutoMapperIfDataType
 from spark_auto_mapper.data_types.if_not import AutoMapperIfNotDataType
-from spark_auto_mapper.data_types.if_not_null_or_empty import AutoMapperIfNotNullOrEmptyDataType
+from spark_auto_mapper.data_types.if_not_null_or_empty import (
+    AutoMapperIfNotNullOrEmptyDataType,
+)
 from spark_auto_mapper.data_types.if_regex import AutoMapperIfRegExDataType
-from spark_auto_mapper.data_types.join_using_delimiter import AutoMapperJoinUsingDelimiterDataType
-from spark_auto_mapper.data_types.split_by_delimiter import AutoMapperSplitByDelimiterDataType
+from spark_auto_mapper.data_types.join_using_delimiter import (
+    AutoMapperJoinUsingDelimiterDataType,
+)
+from spark_auto_mapper.data_types.lpad import AutoMapperLPadDataType
+from spark_auto_mapper.data_types.split_by_delimiter import (
+    AutoMapperSplitByDelimiterDataType,
+)
 from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 
 from spark_auto_mapper.data_types.amount import AutoMapperAmountDataType
@@ -23,6 +30,7 @@ from spark_auto_mapper.data_types.complex.complex import AutoMapperDataTypeCompl
 from spark_auto_mapper.data_types.concat import AutoMapperConcatDataType
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
 from spark_auto_mapper.data_types.date import AutoMapperDateDataType
+from spark_auto_mapper.data_types.decimal import AutoMapperDecimalDataType
 from spark_auto_mapper.data_types.expression import AutoMapperDataTypeExpression
 from spark_auto_mapper.data_types.if_not_null import AutoMapperIfNotNullDataType
 from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
@@ -30,18 +38,33 @@ from spark_auto_mapper.data_types.map import AutoMapperMapDataType
 from spark_auto_mapper.data_types.number import AutoMapperNumberDataType
 from spark_auto_mapper.data_types.complex.struct_type import AutoMapperDataTypeStruct
 from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
+from spark_auto_mapper.data_types.regex_extract import AutoMapperRegExExtractDataType
 from spark_auto_mapper.data_types.substring import AutoMapperSubstringDataType
-from spark_auto_mapper.data_types.substring_by_delimiter import AutoMapperSubstringByDelimiterDataType
+from spark_auto_mapper.data_types.substring_by_delimiter import (
+    AutoMapperSubstringByDelimiterDataType,
+)
 from spark_auto_mapper.data_types.transform import AutoMapperTransformDataType
 from spark_auto_mapper.data_types.trim import AutoMapperTrimDataType
-from spark_auto_mapper.type_definitions.defined_types import AutoMapperAnyDataType, AutoMapperBooleanInputType, \
-    AutoMapperAmountInputType, AutoMapperNumberInputType, AutoMapperDateInputType, AutoMapperTextInputType
-from spark_auto_mapper.type_definitions.native_types import AutoMapperNativeTextType, AutoMapperNativeSimpleType
-from spark_auto_mapper.type_definitions.wrapper_types import AutoMapperWrapperType, AutoMapperColumnOrColumnLikeType
+from spark_auto_mapper.type_definitions.defined_types import (
+    AutoMapperAnyDataType,
+    AutoMapperBooleanInputType,
+    AutoMapperAmountInputType,
+    AutoMapperNumberInputType,
+    AutoMapperDateInputType,
+    AutoMapperTextInputType,
+)
+from spark_auto_mapper.type_definitions.native_types import (
+    AutoMapperNativeTextType,
+    AutoMapperNativeSimpleType,
+)
+from spark_auto_mapper.type_definitions.wrapper_types import (
+    AutoMapperWrapperType,
+    AutoMapperColumnOrColumnLikeType,
+)
 
 _TAutoMapperDataType = TypeVar(
     "_TAutoMapperDataType",
-    bound=Union[AutoMapperNativeSimpleType, AutoMapperDataTypeBase]
+    bound=Union[AutoMapperNativeSimpleType, AutoMapperDataTypeBase],
 )
 
 
@@ -125,6 +148,19 @@ class AutoMapperHelpers:
         """
         return AutoMapperDateTimeDataType(value, formats)
 
+    @staticmethod
+    def decimal(
+        value: AutoMapperAmountInputType, precision: int, scale: int
+    ) -> AutoMapperDecimalDataType:
+        """
+        Specifies the value should be used as a decimal
+        :param value:
+        :param precision: the maximum total number of digits (on both sides of dot)
+        :param scale: the number of digits on right side of dot
+        :return: a decimal automapper type
+        """
+        return AutoMapperDecimalDataType(value, precision, scale)
+
     @staticmethod
     def amount(value: AutoMapperAmountInputType) -> AutoMapperAmountDataType:
         """
@@ -157,7 +193,7 @@ class AutoMapperHelpers:
     @staticmethod
     def concat(
         *args: Union[AutoMapperNativeTextType, AutoMapperWrapperType,
-                     AutoMapperTextLikeBase, AutoMapperDataTypeBase]
+                     AutoMapperTextLikeBase, AutoMapperDataTypeBase, ]
     ) -> AutoMapperConcatDataType:
         """
         concatenates a list of values.  Each value can be a string or a column
@@ -171,7 +207,7 @@ class AutoMapperHelpers:
         column: AutoMapperColumnOrColumnLikeType,
         check: Union[AutoMapperAnyDataType, List[AutoMapperAnyDataType]],
         value: _TAutoMapperDataType,
-        else_: Optional[_TAutoMapperDataType] = None
+        else_: Optional[_TAutoMapperDataType] = None,
     ) -> _TAutoMapperDataType:
         """
         Checks if column matches check_value.  Returns value if it matches else else_
@@ -189,14 +225,14 @@ class AutoMapperHelpers:
             _TAutoMapperDataType,
             AutoMapperIfDataType(
                 column=column, check=check, value=value, else_=else_
-            )
+            ),
         )
 
     @staticmethod
     def if_not(
         column: AutoMapperColumnOrColumnLikeType,
-        check: Union[AutoMapperAnyDataType,
-                     List[AutoMapperAnyDataType]], value: _TAutoMapperDataType
+        check: Union[AutoMapperAnyDataType, List[AutoMapperAnyDataType]],
+        value: _TAutoMapperDataType,
     ) -> _TAutoMapperDataType:
         """
         Checks if column matches check_value.  Returns value if it does not match
@@ -211,14 +247,14 @@ class AutoMapperHelpers:
         # cast it to the inner type so type checking is happy
         return cast(
             _TAutoMapperDataType,
-            AutoMapperIfNotDataType(column=column, check=check, value=value)
+            AutoMapperIfNotDataType(column=column, check=check, value=value),
         )
 
     @staticmethod
     def if_not_null(
         check: AutoMapperColumnOrColumnLikeType,
         value: _TAutoMapperDataType,
-        when_null: Optional[_TAutoMapperDataType] = None
+        when_null: Optional[_TAutoMapperDataType] = None,
     ) -> _TAutoMapperDataType:
         """
         Checks if `check` is null
@@ -235,14 +271,14 @@ class AutoMapperHelpers:
             _TAutoMapperDataType,
             AutoMapperIfNotNullDataType(
                 check=check, value=value, when_null=when_null
-            )
+            ),
         )
 
     @staticmethod
     def if_not_null_or_empty(
         check: AutoMapperColumnOrColumnLikeType,
         value: _TAutoMapperDataType,
-        when_null_or_empty: Optional[_TAutoMapperDataType] = None
+        when_null_or_empty: Optional[_TAutoMapperDataType] = None,
     ) -> _TAutoMapperDataType:
         """
         Checks if `check` is null or empty.
@@ -261,7 +297,7 @@ class AutoMapperHelpers:
                 check=check,
                 value=value,
                 when_null_or_empty=when_null_or_empty
-            )
+            ),
         )
 
     @staticmethod
@@ -269,7 +305,7 @@ class AutoMapperHelpers:
         column: AutoMapperColumnOrColumnLikeType,
         mapping: Dict[Optional[AutoMapperTextInputType],
                       AutoMapperAnyDataType],
-        default: Optional[AutoMapperAnyDataType] = None
+        default: Optional[AutoMapperAnyDataType] = None,
     ) -> AutoMapperDataTypeExpression:
         """
         maps the contents of a column to values
@@ -399,6 +435,23 @@ class AutoMapperHelpers:
             column=column, pattern=pattern, replacement=replacement
         )
 
+    @staticmethod
+    def regex_extract(
+        column: AutoMapperColumnOrColumnLikeType, pattern: str, index: int
+    ) -> AutoMapperRegExExtractDataType:
+        """
+        Extracts a specific group matched by a regex from a specified column. If there
+        was no match or the requested group does not exist, an empty string is returned.
+
+        :param column: column whose contents to replace
+        :param pattern: pattern containing groups to match
+        :param index: index of the group to return (1-indexed, use 0 to return the whole matched string)
+        :return: a regex_extract automapper type
+        """
+        return AutoMapperRegExExtractDataType(
+            column=column, pattern=pattern, index=index
+        )
+
     @staticmethod
     def trim(
         column: AutoMapperColumnOrColumnLikeType
@@ -411,6 +464,20 @@ class AutoMapperHelpers:
         """
         return AutoMapperTrimDataType(column=column)
 
+    @staticmethod
+    def lpad(
+        column: AutoMapperColumnOrColumnLikeType, length: int, pad: str
+    ) -> AutoMapperLPadDataType:
+        """
+        Returns column value, left-padded with pad to a length of length. If column value is longer than length,
+        the return value is shortened to length characters.
+
+        :param column: column whose contents to left pad
+        :param length: the desired length of the final string
+        :param pad: the character to use to pad the string to the desired length
+        """
+        return AutoMapperLPadDataType(column=column, length=length, pad=pad)
+
     @staticmethod
     def hash(
         *args: Union[AutoMapperNativeTextType, AutoMapperWrapperType,
@@ -441,7 +508,7 @@ class AutoMapperHelpers:
         column: AutoMapperColumnOrColumnLikeType,
         check: Union[str, List[str]],
         value: _TAutoMapperDataType,
-        else_: Optional[_TAutoMapperDataType] = None
+        else_: Optional[_TAutoMapperDataType] = None,
     ) -> _TAutoMapperDataType:
         """
         Checks if column matches check_value.  Returns value if it matches else else_
@@ -459,7 +526,7 @@ class AutoMapperHelpers:
             _TAutoMapperDataType,
             AutoMapperIfRegExDataType(
                 column=column, check=check, value=value, else_=else_
-            )
+            ),
         )
 
     @staticmethod
@@ -497,7 +564,7 @@ class AutoMapperHelpers:
         # cast it to the inner type so type checking is happy
         return cast(
             List[_TAutoMapperDataType],
-            AutoMapperTransformDataType(column=column, value=value)
+            AutoMapperTransformDataType(column=column, value=value),
         )
 
     @staticmethod
@@ -533,7 +600,7 @@ class AutoMapperHelpers:
         )
 
     @staticmethod
-    def float(value: AutoMapperDataTypeBase) -> 'AutoMapperDataTypeBase':
+    def float(value: AutoMapperDataTypeBase) -> "AutoMapperDataTypeBase":
         """
         Converts column to float
 
@@ -543,7 +610,7 @@ class AutoMapperHelpers:
         from spark_auto_mapper.data_types.float import AutoMapperFloatDataType
 
         return cast(
-            'AutoMapperDataTypeBase', AutoMapperFloatDataType(value=value)
+            "AutoMapperDataTypeBase", AutoMapperFloatDataType(value=value)
         )
 
     @staticmethod
@@ -564,6 +631,36 @@ class AutoMapperHelpers:
             "AutoMapperDataTypeBase", AutoMapperFlattenDataType(column=column)
         )
 
+    @staticmethod
+    def first_valid_column(
+        *columns: AutoMapperColumnOrColumnLikeType,
+    ) -> "AutoMapperDataTypeBase":
+        """
+        Allows for columns to be defined based in which a source column may not exist. If the optional source column does
+         not exist, the "default" column definition is used instead.
+
+         :return: a optional automapper type
+        """
+        from spark_auto_mapper.data_types.first_valid_column import AutoMapperFirstValidColumnType
+
+        return AutoMapperFirstValidColumnType(*columns)
+
+    @staticmethod
+    def if_column_exists(
+        column: AutoMapperColumnOrColumnLikeType,
+        if_exists: Optional[_TAutoMapperDataType],
+        if_not_exists: Optional[_TAutoMapperDataType]
+    ) -> "AutoMapperDataTypeBase":
+        """
+        check the if the column exists if exists returns if_exists if not if_not_exists
+        :return: a optional automapper type
+        """
+        from spark_auto_mapper.data_types.if_column_exists import AutoMapperIfColumnExistsType
+
+        return AutoMapperIfColumnExistsType(
+            column=column, if_exists=if_exists, if_not_exists=if_not_exists
+        )
+
     @staticmethod
     def array(value: AutoMapperDataTypeBase) -> "AutoMapperDataTypeBase":
         """
